@@ -2,7 +2,7 @@ package Test2::Compare::Delta;
 use strict;
 use warnings;
 
-our $VERSION = '0.000042';
+our $VERSION = '0.000045';
 
 use Test2::Util::HashBase qw{verified id got chk children dne exception};
 
@@ -273,15 +273,14 @@ sub table_rows {
 sub table {
     my $self = shift;
 
-    my @out;
-
+    my @diag;
     my $header = $self->table_header;
     my $rows   = $self->table_rows;
 
     my $max = exists $ENV{TS_MAX_DELTA} ? $ENV{TS_MAX_DELTA} : 25;
     if ($max && @$rows > $max) {
         @$rows = @{$rows}[0 .. ($max - 1)];
-        push @out => (
+        @diag = (
             "************************************************************",
             sprintf("* Stopped after %-42.42s *", "$max differences."),
             "* Set the TS_MAX_DELTA environment var to raise the limit. *",
@@ -290,17 +289,17 @@ sub table {
         );
     }
 
-    my @no_collapse = grep { $COLUMNS{$COLUMN_ORDER[$_]}->{no_collapse} } 0 .. $#COLUMN_ORDER;
-    unshift @out => Test2::Util::Table::table(
-        header      => $header,
-        rows        => $rows,
-        collapse    => 1,
-        sanitize    => 1,
-        mark_tail   => 1,
-        no_collapse => \@no_collapse,
+    return (
+        Test2::Util::Table::table(
+            header      => $header,
+            rows        => $rows,
+            collapse    => 1,
+            sanitize    => 1,
+            mark_tail   => 1,
+            no_collapse => [grep { $COLUMNS{$COLUMN_ORDER[$_]}->{no_collapse} } 0 .. $#COLUMN_ORDER],
+        ),
+        @diag,
     );
-
-    return @out;
 }
 
 sub diag {
@@ -324,7 +323,7 @@ structures.
 =head1 DESCRIPTION
 
 This is used by L<Test2::Compare>. When data structures are compared a
-delta will be returned. Deltas are a tree datastructure that represent all the
+delta will be returned. Deltas are a tree data structure that represent all the
 differences between two other data structures.
 
 =head1 METHODS
