@@ -2,7 +2,7 @@ package Test2::Tools::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000042';
+our $VERSION = '0.000045';
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -64,7 +64,7 @@ our @EXPORT_OK = qw{
     in_set not_in_set check_set
     item field call call_list call_hash prop check all_items all_keys all_vals all_values
     end filter_items
-    T F D DNE FDNE E
+    T F D DF DNE FDNE E
     event fail_events
     exact_ref
 };
@@ -154,6 +154,15 @@ sub D() {
     );
 }
 
+sub DF() {
+    my @caller = caller;
+    Test2::Compare::Custom->new(
+        code => sub { defined $_ && ! $_ ? 1 : 0 }, name => 'DEFINED BUT FALSE', operator => 'DEFINED() && FALSE()',
+        file => $caller[1],
+        lines => [$caller[2]],
+    );
+}
+
 sub DNE() {
     my @caller = caller;
     Test2::Compare::Custom->new(
@@ -615,7 +624,7 @@ failure, they will not be displayed when the comparison is successful. The
 boolean true/false result of the comparison is returned.
 
 This is the strict checker. The strict checker requires a perfect match between
-C<$got> and C<$expect>. All hash fields must be specfied, all array items must
+C<$got> and C<$expect>. All hash fields must be specified, all array items must
 be present, etc. All non-scalar/hash/array/regex references must be identical
 (same memory address). Scalar, hash and array references will be traversed and
 compared. Regex references will be compared to see if they have the same
@@ -787,6 +796,20 @@ This will fail:
 
     is(undef, D(), 'foo is defined');
 
+=item $check = DF()
+
+This is to verify that the value in the C<$got> structure is defined but false.
+Any false value other than C<undef> will pass.
+
+This will pass:
+
+    is(0, DF(), 'foo is defined but false');
+
+These will fail:
+
+    is(undef, DF(), 'foo is defined but false');
+    is(1, DF(), 'foo is defined but false');
+
 =item $check = DNE()
 
 This can be used to check that no value exists. This is useful to check the end
